@@ -1,7 +1,8 @@
+#[export]
 cqtest <- function(x, treat, block, logged = FALSE) {
   k <- Rfast::sort_unique.length(treat)
-  cj <- Rfast::group.sum(x, treat)
-  ri <- Rfast::group.sum(x, block)  
+  cj <- Rfast::group(x, treat)
+  ri <- Rfast::group(x, block)  
   N <- sum(cj)
   up <- k * (k - 1) * sum(cj^2) - (k - 1) * N^2
   stat <- up / (k * N - sum(ri^2) )
